Actions, Resources, and Condition Keys for Amazon EC2 Image Builder - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for Amazon EC2 Image Builder

Amazon EC2 Image Builder (service prefix: `imagebuilder` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon EC2 Image Builder
- Resource Types Defined by Amazon EC2 Image Builder
- Condition Keys for Amazon EC2 Image Builder

## Actions Defined by Amazon EC2 Image Builder

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CancelImageCreation | Cancel an image creation | Write | image* |  |
CreateComponent | Create a new component | Write | component* |  |
kmsKey |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDistributionConfiguration | Create a new distribution configuration | Write | distributionConfiguration* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateImage | Create a new image | Write | image* |  | imagebuilder:GetImageRecipe imagebuilder:GetInfrastructureConfiguration
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateImagePipeline | Create a new image pipeline | Write | imagePipeline* |  | imagebuilder:GetImageRecipe
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateImageRecipe | Create a new Image Recipe | Write | imageRecipe* |  | imagebuilder:GetComponent
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateInfrastructureConfiguration | Create a new infrastructure configuration | Write | infrastructureConfiguration* |  | iam:PassRole
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteComponent | Delete a component | Write | component* |  |
DeleteDistributionConfiguration | Delete a distribution configuration | Write | distributionConfiguration* |  |
DeleteImage | Delete an image | Write | image* |  |
DeleteImagePipeline | Delete an image pipeline | Write | imagePipeline* |  |
DeleteImageRecipe | Grants permission to delete an image recipe | Write | imageRecipe* |  |
DeleteInfrastructureConfiguration | Delete an infrastructure configuration | Write | infrastructureConfiguration* |  |
GetComponent | View details about a component | Read | component* |  |
GetComponentPolicy | View the resource policy associated with a component | Permissions management | component* |  |
GetDistributionConfiguration | View details about a distribution configuration | Read | distributionConfiguration* |  |
GetImage | View details about an image | Read | image* |  |
| aws:ResourceTag/${TagKey} |
GetImagePipeline | View details about an image pipeline | Read | imagePipeline* |  |
GetImagePolicy | View the resource policy associated with an image | Permissions management | image* |  |
GetImageRecipe | View details about an image recipe | Read | imageRecipe* |  |
GetImageRecipePolicy | View the resource policy associated with an image recipe | Permissions management | imageRecipe* |  |
GetInfrastructureConfiguration | View details about an infrastructure configuration | Read | infrastructureConfiguration* |  |
ListComponentBuildVersions | List the component build versions in your account | List | componentVersion* |  |
ListComponents | List the component versions owned by or shared with your account | List |  |  |
ListDistributionConfigurations | List the distribution configurations in your account | List |  |  |
ListImageBuildVersions | List the image build versions in your account | List | imageVersion* |  |
ListImagePipelines | List the image pipelines in your account | List |  |  |
ListImageRecipes | List the image recipes owned by or shared with your account | List |  |  |
ListImages | List the image versions owned by or shared with your account | List |  |  |
ListInfrastructureConfigurations | List the infrastructure configurations in your account | List |  |  |
ListTagsForResource | List tag for an Image Builder resource | Read | component |  |
distributionConfiguration |  |
image |  |
imagePipeline |  |
imageRecipe |  |
infrastructureConfiguration |  |
| aws:ResourceTag/${TagKey} |
PutComponentPolicy | Set the resource policy associated with a component | Permissions management | component* |  |
PutImagePolicy | Set the resource policy associated with an image | Permissions management | image* |  |
PutImageRecipePolicy | Set the resource policy associated with an image recipe | Permissions management | imageRecipe* |  |
StartImagePipelineExecution | Create a new image from a pipeline | Write | imagePipeline* |  | imagebuilder:GetImagePipeline
TagResource | Tag an Image Builder resource | Tagging | component |  |
distributionConfiguration |  |
image |  |
imagePipeline |  |
imageRecipe |  |
infrastructureConfiguration |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Untag an Image Builder resource | Tagging | component |  |
distributionConfiguration |  |
image |  |
imagePipeline |  |
imageRecipe |  |
infrastructureConfiguration |  |
| aws:ResourceTag/${TagKey} aws:TagKeys |
UpdateDistributionConfiguration | Update an existing distribution configuration | Write | distributionConfiguration* |  |
UpdateImagePipeline | Update an existing image pipeline | Write | imagePipeline* |  |
UpdateInfrastructureConfiguration | Update an existing infrastructure configuration | Write | infrastructureConfiguration* |  | iam:PassRole
| aws:ResourceTag/${TagKey} |

## Resource Types Defined by Amazon EC2 Image Builder

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
component | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:component/$ { ComponentName}/$ { ComponentVersion}/$ { ComponentBuildVersion}` | aws:ResourceTag/${TagKey}
componentVersion | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:component/$ { ComponentName}/$ { ComponentVersion}` | aws:ResourceTag/${TagKey}
distributionConfiguration | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:distribution-configuration/$ { DistributionConfigurationName}` | aws:ResourceTag/${TagKey}
image | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:image/$ { ImageName}/$ { ImageVersion}/$ { ImageBuildVersion}` | aws:ResourceTag/${TagKey}
imageVersion | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:image/$ { ImageName}/$ { ImageVersion}` | aws:ResourceTag/${TagKey}
imageRecipe | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:image-recipe/$ { ImageRecipeName}/$ { ImageRecipeVersion}` | aws:ResourceTag/${TagKey}
imagePipeline | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:image-pipeline/$ { ImagePipelineName}` | aws:ResourceTag/${TagKey}
infrastructureConfiguration | `arn:$ { Partition}:imagebuilder:$ { Region}:$ { Account}:infrastructure-configuration/$ { ResourceId}` | aws:ResourceTag/${TagKey}
kmsKey | `arn:$ { Partition}:kms:$ { Region}:$ { Account}:key/$ { KeyId}` |

## Condition Keys for Amazon EC2 Image Builder

Amazon EC2 Image Builder defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/$ { TagKey} | Filters actions by the presence of tag key-value pairs in the request | String
aws:ResourceTag/$ { TagKey} | Filters actions by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions by the presence of tag keys in the request | String